==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/pmhplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>PMH</name>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="143"/>
        <source>New past medical history</source>
        <translation>Nouvel antécédent</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="144"/>
        <source>Remove past medical history</source>
        <translation>Enlever l&apos;antécédent</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="145"/>
        <source>Create a new category</source>
        <translation>Créer une nouvelle catégorie</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="146"/>
        <source>Remove category</source>
        <translation>Retirer la catégorie</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="147"/>
        <source>Past medical history category manager</source>
        <translation>Gestionnaire des catégories pour les antécédents</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="149"/>
        <source>Not defined</source>
        <translation>Non défini</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="150"/>
        <source>Chronic disease</source>
        <translation>Maladie chronique</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="151"/>
        <source>Chronic disease without acute episode</source>
        <translation>Maladie chronique avec épisodes aigus</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="152"/>
        <source>Acute disease</source>
        <translation>Maladie aiguë</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="153"/>
        <source>Risk factor</source>
        <translation>Facteur de risque</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="155"/>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="156"/>
        <source>In remission</source>
        <translation>En rémission</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="157"/>
        <source>Quiescent</source>
        <translation>Quiescent</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="158"/>
        <source>Cured</source>
        <translation>Guéri</translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhModeWidget</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhmodewidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhmode.cpp" line="294"/>
        <source>Remove PMHx</source>
        <translation>Effacer un antécédent</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhmode.cpp" line="295"/>
        <source>Do you really want to remove the PMHx called &lt;br /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;%1&lt;/b&gt;?</source>
        <translation>Voulez-vous réellement effacer l&apos;antécédent nommé &lt;br /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhPreferencesWidget</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="20"/>
        <source>Data saving</source>
        <translation>Sauvegarde des données</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="26"/>
        <source>Always ask for confirmation before deletion</source>
        <translation>Toujours demander confirmation avant d&apos;effacer</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="36"/>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="42"/>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="61"/>
        <source>Category background color</source>
        <translation>Couleur de fond pour les catégories</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="71"/>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="90"/>
        <source>Category foreground color</source>
        <translation>Couleur de caractère pour les catégories</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="100"/>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="103"/>
        <source>PMHx background color</source>
        <translation>Couleur de fond pour les ATCD</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="129"/>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="148"/>
        <source>PMHx foreground color</source>
        <translation>Couleur de caractère pour les ATCD</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="161"/>
        <source>Fonts</source>
        <translation>Polices de caractère</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="167"/>
        <source>Category font</source>
        <translation>Catégories</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="174"/>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="188"/>
        <source>Change...</source>
        <translation>Modifier...</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="181"/>
        <source>PMHx font</source>
        <translation>Antécédents</translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhViewer</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="29"/>
        <source>Past Medical History</source>
        <translation>Antécédents</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="222"/>
        <source>Patient</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="46"/>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="189"/>
        <source>General information</source>
        <translation>Informations générales</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="52"/>
        <source>Personal label</source>
        <translation>Intitulé personnalisé</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="62"/>
        <source>Type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="72"/>
        <source>Status</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="82"/>
        <source>Confidence index</source>
        <translation>Indice de confiance</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="111"/>
        <source>Privacy</source>
        <translation>Accès privé</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="118"/>
        <source>Make this PMHx private</source>
        <translation>Privatiser cet antécédent</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="170"/>
        <source>Category</source>
        <translation>Catégorie</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="195"/>
        <source>Date</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="209"/>
        <source>Manage ICD10 Codes</source>
        <translation>Gérer les codes CIM10</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="132"/>
        <source>Episodes</source>
        <translation>Épisodes</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="157"/>
        <source>Comment</source>
        <translation>Commentaire</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="142"/>
        <source>Management</source>
        <translation>Prise en charge</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="147"/>
        <source>Contacts</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="152"/>
        <source>Links</source>
        <translation>Liens</translation>
    </message>
</context>
<context>
    <name>PMH::PmhCategoryModel</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhcategorymodel.cpp" line="1224"/>
        <location filename="../../plugins/pmhplugin/pmhcategorymodel.cpp" line="1234"/>
        <source>Patient PMHx synthesis</source>
        <translation>Synthèse des ATCD du patient</translation>
    </message>
</context>
<context>
    <name>PMH::PmhCreatorDialog</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhcreatordialog.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhcreatordialog.cpp" line="55"/>
        <source>Past Medical History Creator</source>
        <translation>Créateur d&apos;antécédents</translation>
    </message>
</context>
<context>
    <name>PMH::PmhEpisodeModel</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhepisodemodel.cpp" line="264"/>
        <source>Starting date</source>
        <translation>Date de début</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhepisodemodel.cpp" line="265"/>
        <source>Ending date</source>
        <translation>Date de fin</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhepisodemodel.cpp" line="266"/>
        <source>Label</source>
        <translation>Libellé</translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhepisodemodel.cpp" line="267"/>
        <source>ICD10 coding</source>
        <translation>Codage CIM10</translation>
    </message>
</context>
<context>
    <name>PMH::PmhEpisodeViewer</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhepisodeviewer.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PMH::PmhPlugin</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhplugin.cpp" line="84"/>
        <location filename="../../plugins/pmhplugin/pmhplugin.cpp" line="100"/>
        <source>Initializing PMHx database plugin...</source>
        <translation>Initialisation de la base de données des antécédents...</translation>
    </message>
</context>
<context>
    <name>PMH::PmhViewer</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.cpp" line="267"/>
        <source>Replacing pmh data</source>
        <translation>Remplacement des données de l&apos;antécédent</translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.8.0.orig.tar.gz: freemedforms-0.8.0/global_resources/translations/pmhplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>PMH</name>
    <message>
        <source>New past medical history</source>
        <translation>Nouvel antécédent</translation>
    </message>
    <message>
        <source>Remove past medical history</source>
        <translation>Enlever l&apos;antécédent</translation>
    </message>
    <message>
        <source>Create a new category</source>
        <translation>Créer une nouvelle catégorie</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Retirer la catégorie</translation>
    </message>
    <message>
        <source>Past medical history category manager</source>
        <translation>Gestionnaire des catégories pour les antécédents</translation>
    </message>
    <message>
        <source>Not defined</source>
        <translation>Non défini</translation>
    </message>
    <message>
        <source>Chronic disease</source>
        <translation>Maladie chronique</translation>
    </message>
    <message>
        <source>Chronic disease without acute episode</source>
        <translation>Maladie chronique avec épisodes aigus</translation>
    </message>
    <message>
        <source>Acute disease</source>
        <translation>Maladie aiguë</translation>
    </message>
    <message>
        <source>Risk factor</source>
        <translation>Facteur de risque</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Actif</translation>
    </message>
    <message>
        <source>In remission</source>
        <translation>En rémission</translation>
    </message>
    <message>
        <source>Quiescent</source>
        <translation>Quiescent</translation>
    </message>
    <message>
        <source>Cured</source>
        <translation>Guéri</translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhModeWidget</name>
    <message>
        <source>Remove PMHx</source>
        <translation>Effacer un antécédent</translation>
    </message>
    <message>
        <source>Do you really want to remove the PMHx called &lt;br /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;%1&lt;/b&gt;?</source>
        <translation>Voulez-vous réellement effacer l&apos;antécédent nommé &lt;br /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;%1&lt;/b&gt;?</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhPlugin</name>
    <message>
        <source>Initializing PMHx database plugin...</source>
        <translation>Initialisation de la base de données des antécédents...</translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhPreferencesWidget</name>
    <message>
        <source>Data saving</source>
        <translation>Sauvegarde des données</translation>
    </message>
    <message>
        <source>Always ask for confirmation before deletion</source>
        <translation>Toujours demander confirmation avant d&apos;effacer</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
    <message>
        <source>Category background color</source>
        <translation>Couleur de fond pour les catégories</translation>
    </message>
    <message>
        <source>Category foreground color</source>
        <translation>Couleur de caractère pour les catégories</translation>
    </message>
    <message>
        <source>PMHx background color</source>
        <translation>Couleur de fond pour les ATCD</translation>
    </message>
    <message>
        <source>PMHx foreground color</source>
        <translation>Couleur de caractère pour les ATCD</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Polices de caractère</translation>
    </message>
    <message>
        <source>Category font</source>
        <translation>Catégories</translation>
    </message>
    <message>
        <source>Change...</source>
        <translation>Modifier...</translation>
    </message>
    <message>
        <source>PMHx font</source>
        <translation>Antécédents</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhViewer</name>
    <message>
        <source>Past Medical History</source>
        <translation>Antécédents</translation>
    </message>
    <message>
        <source>General information</source>
        <translation>Informations générales</translation>
    </message>
    <message>
        <source>Personal label</source>
        <translation>Intitulé personnalisé</translation>
    </message>
    <message>
        <source>Confidence index</source>
        <translation>Indice de confiance</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Accès privé</translation>
    </message>
    <message>
        <source>Make this PMHx private</source>
        <translation>Privatiser cet antécédent</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Catégorie</translation>
    </message>
    <message>
        <source>Manage ICD10 Codes</source>
        <translation>Gérer les codes CIM10</translation>
    </message>
    <message>
        <source>Episodes</source>
        <translation>Épisodes</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Commentaire</translation>
    </message>
    <message>
        <source>Management</source>
        <translation>Prise en charge</translation>
    </message>
    <message>
        <source>Links</source>
        <translation>Liens</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <source>Type</source>
        <translation></translation>
    </message>
    <message>
        <source>Status</source>
        <translation></translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation></translation>
    </message>
    <message>
        <source>Date</source>
        <translation></translation>
    </message>
    <message>
        <source>Patient</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PMH::PmhCategoryModel</name>
    <message>
        <source>Patient PMHx synthesis</source>
        <translation>Synthèse des ATCD du patient</translation>
    </message>
</context>
<context>
    <name>PMH::PmhCreatorDialog</name>
    <message>
        <source>Past Medical History Creator</source>
        <translation>Créateur d&apos;antécédents</translation>
    </message>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PMH::PmhEpisodeModel</name>
    <message>
        <source>Starting date</source>
        <translation>Date de début</translation>
    </message>
    <message>
        <source>Ending date</source>
        <translation>Date de fin</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Libellé</translation>
    </message>
    <message>
        <source>ICD10 coding</source>
        <translation>Codage CIM10</translation>
    </message>
</context>
<context>
    <name>PMH::PmhEpisodeViewer</name>
    <message>
        <source>Form</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PMH::PmhViewer</name>
    <message>
        <source>Replacing pmh data</source>
        <translation>Remplacement des données de l&apos;antécédent</translation>
    </message>
</context>
</TS>
